batch_evaluate_fitness

Function batch_evaluate_fitness 

pub fn batch_evaluate_fitness(
    genomes: &[Vec<f64>],
    inputs: &[f64],
    target: f64,
) -> Vec<f64>
Evaluate fitness for a population of weight vectors against a target.

Fitness = -MSE(genome_weights, target_outputs) for each genome applied to a simple linear evaluation: output = sum(w_i * input_i).